# -*- coding: utf-8 -*-
'''
National Instruments SystemLink Asset Performance Management Constants
'''
from __future__ import absolute_import, print_function, unicode_literals

from enum import IntEnum  # pylint: disable=import-error,3rd-party-module-not-gated

DATA_DIRECTORY = 'Data'
ASSETS_DIRECTORY = 'Assets'
USER_DEFINED_DIRECTORY = 'UserDefined'
USER_DEFINED_ENABLE_FILE = 'UserDefined.enable'

BUS_TYPE_DEFAULT_VALUE = 'BuiltInSystem'

MODEL_NAME_KEY = 'ModelName'
MODEL_NUMBER_KEY = 'ModelNumber'
SERIAL_NUMBER_KEY = 'SerialNumber'
VENDOR_NAME_KEY = 'VendorName'
VENDOR_NUMBER_KEY = 'VendorNumber'
BUS_TYPE_KEY = 'BusType'

ASSET_CLASSS_KEY = 'AssetClass'

SELF_CALIBRATION_KEY = 'SelfCalibration'
EXTERNAL_CALIBRATION_KEY = 'ExternalCalibration'

ASSET_NAME_KEY = 'AssetName'
FIRMWARE_VERSION_KEY = 'FirmwareVersion'
HARDWRE_VERSION_KEY = 'HardwareVersion'
VISA_RESOURCE_NAME_KEY = 'VisaResourceName'
SUPPORTS_SELF_CALIBRATION_KEY = 'SupportsSelfCalibration'
SUPPORTS_EXTERNAL_CALIBRATION_KEY = 'SupportsExternalCalibration'
LOCATION_KEY = 'Location'

RESOURCE_URI_KEY = 'ResourceUri'
SLOT_NUMBER_KEY = 'SlotNumber'
PARENT_KEY = 'Parent'

CALIBARTION_DATE_KEY = 'Date'
NEXT_RECOMMENDED_DATE_KEY = 'NextRecommendedDate'  # Not parsed
RECOMMENDED_INTERVAL_KEY = 'RecommendedInterval'
IS_LIMITED_KEY = 'IsLimited'
COMMENTS_KEY = 'Comments'
CHECKSUM_KEY = 'Checksum'
SUPPORTS_LIMITED_KEY = 'SupportsLimited'
SUPPORTS_WRITE_KEY = 'SupportsWrite'
OPERATOR_KEY = 'Operator'

DISPLAY_NAME_KEY = 'DisplayName'
USER_ID_KEY = 'UserId'

SUPPORTS_ANY_CALIBRATION_MESSAGE_KEY = 'SupportsAnyCalibration'

LOCATION_RESOURCE_URI_MESSAGE_KEY = LOCATION_KEY + RESOURCE_URI_KEY
LOCATION_SLOT_NUMBER_MESSAGE_KEY = LOCATION_KEY + SLOT_NUMBER_KEY
LOCATION_PARENT_MESSAGE_KEY = LOCATION_KEY + PARENT_KEY

CALIBRATION_KEYWORD = 'Calibration'

SELF_CALIBRATION_DATE_MESSAGE_KEY = SELF_CALIBRATION_KEY + \
    CALIBRATION_KEYWORD + CALIBARTION_DATE_KEY
SELF_CALIBRATION_IS_LIMITED_MESSAGE_KEY = SELF_CALIBRATION_KEY + IS_LIMITED_KEY
SELF_CALIBRATION_OPERATOR_DISPLAY_NAME_MESSAGE_KEY = SELF_CALIBRATION_KEY + \
    OPERATOR_KEY + DISPLAY_NAME_KEY
SELF_CALIBRATION_OPERATOR_USER_ID_MESSAGE_KEY = SELF_CALIBRATION_KEY + \
    OPERATOR_KEY + USER_ID_KEY

EXTERNAL_CALIBRATION_DATE_MESSAGE_KEY = EXTERNAL_CALIBRATION_KEY + \
    CALIBRATION_KEYWORD + CALIBARTION_DATE_KEY
EXTERNAL_CALIBRATION_COMMENTS_MESSAGE_KEY = EXTERNAL_CALIBRATION_KEY + COMMENTS_KEY
EXTERNAL_CALIBRATION_CHECKSUM_MESSAGE_KEY = EXTERNAL_CALIBRATION_KEY + CHECKSUM_KEY
EXTERNAL_CALIBRATION_RECOMMENDED_INTERVAL_MESSAGE_KEY = EXTERNAL_CALIBRATION_KEY + \
    RECOMMENDED_INTERVAL_KEY
EXTERNAL_CALIBRATION_NEXT_RECOMMENDED_DATE_MESSAGE_KEY = EXTERNAL_CALIBRATION_KEY + \
    NEXT_RECOMMENDED_DATE_KEY
EXTERNAL_CALIBRATION_IS_LIMITED_MESSAGE_KEY = EXTERNAL_CALIBRATION_KEY + IS_LIMITED_KEY
EXTERNAL_CALIBRATION_SUPPORTS_LIMITED_MESSAGE_KEY = EXTERNAL_CALIBRATION_KEY + \
    SUPPORTS_LIMITED_KEY
EXTERNAL_CALIBRATION_SUPPORTS_WRITE_MESSAGE_KEY = EXTERNAL_CALIBRATION_KEY + \
    SUPPORTS_WRITE_KEY
EXTERNAL_CALIBRATION_OPERATOR_DISPLAY_NAME_MESSAGE_KEY = EXTERNAL_CALIBRATION_KEY + \
    OPERATOR_KEY + DISPLAY_NAME_KEY
EXTERNAL_CALIBRATION_OPERATOR_USER_ID_MESSAGE_KEY = EXTERNAL_CALIBRATION_KEY + \
    OPERATOR_KEY + USER_ID_KEY

RESERVED_KEYS = {
    SUPPORTS_ANY_CALIBRATION_MESSAGE_KEY,
    LOCATION_RESOURCE_URI_MESSAGE_KEY,
    LOCATION_SLOT_NUMBER_MESSAGE_KEY,
    LOCATION_PARENT_MESSAGE_KEY,
    SELF_CALIBRATION_DATE_MESSAGE_KEY,
    SELF_CALIBRATION_IS_LIMITED_MESSAGE_KEY,
    SELF_CALIBRATION_OPERATOR_DISPLAY_NAME_MESSAGE_KEY,
    SELF_CALIBRATION_OPERATOR_USER_ID_MESSAGE_KEY,
    EXTERNAL_CALIBRATION_DATE_MESSAGE_KEY,
    EXTERNAL_CALIBRATION_COMMENTS_MESSAGE_KEY,
    EXTERNAL_CALIBRATION_CHECKSUM_MESSAGE_KEY,
    EXTERNAL_CALIBRATION_RECOMMENDED_INTERVAL_MESSAGE_KEY,
    EXTERNAL_CALIBRATION_NEXT_RECOMMENDED_DATE_MESSAGE_KEY,
    EXTERNAL_CALIBRATION_IS_LIMITED_MESSAGE_KEY,
    EXTERNAL_CALIBRATION_SUPPORTS_LIMITED_MESSAGE_KEY,
    EXTERNAL_CALIBRATION_SUPPORTS_WRITE_MESSAGE_KEY,
    EXTERNAL_CALIBRATION_OPERATOR_DISPLAY_NAME_MESSAGE_KEY,
    EXTERNAL_CALIBRATION_OPERATOR_USER_ID_MESSAGE_KEY
}


class PublishUserDefinedAssetsStatusCode(IntEnum):
    '''
    Enumeration defining possible status codes for the `publish_user_defined_assets` function
    '''
    INTERNAL_ERROR = -2
    AMQP_ERROR = -1
    SUCCESS = 0
    PARTIAL_SUCCESS = 1
    NO_JSON_FILES = 2
